==> huaweicloudsdkprojectman-3.0.45-py2.py3-none-any.whl: huaweicloudsdkprojectman/v4/model/metric_request_v2_dividend.py <==
# coding: utf-8

import pprint
import re

import six





class MetricRequestV2Dividend:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'custom_fields': 'list[MetricRequestV2DividendCustomFields]'
    }

    attribute_map = {
        'custom_fields': 'custom_fields'
    }

    def __init__(self, custom_fields=None):
        """MetricRequestV2Dividend - a model defined in huaweicloud sdk"""
        
        

        self._custom_fields = None
        self.discriminator = None

        if custom_fields is not None:
            self.custom_fields = custom_fields

    @property
    def custom_fields(self):
        """Gets the custom_fields of this MetricRequestV2Dividend.

        自定义类型过滤条件

        :return: The custom_fields of this MetricRequestV2Dividend.
        :rtype: list[MetricRequestV2DividendCustomFields]
        """
        return self._custom_fields

    @custom_fields.setter
    def custom_fields(self, custom_fields):
        """Sets the custom_fields of this MetricRequestV2Dividend.

        自定义类型过滤条件

        :param custom_fields: The custom_fields of this MetricRequestV2Dividend.
        :type: list[MetricRequestV2DividendCustomFields]
        """
        self._custom_fields = custom_fields

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MetricRequestV2Dividend):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkprojectman-3.0.51-py2.py3-none-any.whl: huaweicloudsdkprojectman/v4/model/metric_request_v2_dividend.py <==
# coding: utf-8

import re
import six





class MetricRequestV2Dividend:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'custom_fields': 'list[MetricRequestV2DividendCustomFields]'
    }

    attribute_map = {
        'custom_fields': 'custom_fields'
    }

    def __init__(self, custom_fields=None):
        """MetricRequestV2Dividend - a model defined in huaweicloud sdk"""
        
        

        self._custom_fields = None
        self.discriminator = None

        if custom_fields is not None:
            self.custom_fields = custom_fields

    @property
    def custom_fields(self):
        """Gets the custom_fields of this MetricRequestV2Dividend.

        自定义类型过滤条件

        :return: The custom_fields of this MetricRequestV2Dividend.
        :rtype: list[MetricRequestV2DividendCustomFields]
        """
        return self._custom_fields

    @custom_fields.setter
    def custom_fields(self, custom_fields):
        """Sets the custom_fields of this MetricRequestV2Dividend.

        自定义类型过滤条件

        :param custom_fields: The custom_fields of this MetricRequestV2Dividend.
        :type: list[MetricRequestV2DividendCustomFields]
        """
        self._custom_fields = custom_fields

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MetricRequestV2Dividend):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
